translate.convert.mozfunny2prop

Package translate :: Package convert :: Module mozfunny2prop |
[hide private]
[frames] | no frames]

# Module mozfunny2prop

source code

converts funny mozilla files to properties files

Functions | [hide private]
inc2prop(lines) convert a .inc file with #defines in it to a properties file | source code
it2prop(lines, encoding="cp1252") convert a pseudo-properties .it file to a conventional properties file | source code
funny2prop(lines, itencoding="cp1252") | source code
inc2po(inputfile, outputfile, templatefile, encoding=None, pot=False, duplicatestyle="msgctxt") wraps prop2po but converts input/template files to properties first | source code
it2po(inputfile, outputfile, templatefile, encoding="cp1252", pot=False, duplicatestyle="msgctxt") wraps prop2po but converts input/template files to properties first | source code
ini2po(inputfile, outputfile, templatefile, encoding="UTF-8", pot=False, duplicatestyle="msgctxt") | source code
main(argv=None) | source code

Imports: string, prop2po, StringIO